@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from shlex import quote
 
 import pytest
@@ -8,10 +10,10 @@ from virtualenv.activation import BatchActivator
 @pytest.mark.usefixtures("activation_python")
 def test_batch(activation_tester_class, activation_tester, tmp_path):
     version_script = tmp_path / "version.bat"
-    version_script.write_text("ver")
+    version_script.write_text("ver", encoding="utf-8")
 
     class Batch(activation_tester_class):
-        def __init__(self, session):
+        def __init__(self, session) -> None:
             super().__init__(BatchActivator, session, None, "activate.bat", "bat")
             self._version_cmd = [str(version_script)]
             self._invoke_script = []
@@ -21,8 +23,7 @@ def test_batch(activation_tester_class, activation_tester, tmp_path):
             self.unix_line_ending = False
 
         def _get_test_lines(self, activate_script):
-            # for BATCH utf-8 support need change the character code page to 650001
-            return ["@echo off", "", "chcp 65001 1>NUL"] + super()._get_test_lines(activate_script)
+            return ["@echo off", *super()._get_test_lines(activate_script)]
 
         def quote(self, s):
             """double quotes needs to be single, and single need to be double"""
